<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="cs" sourcelanguage="en">
<context>
    <name>Alert</name>
    <message>
        <location filename="../src/alert.cpp" line="236"/>
        <source>Close (%1)</source>
        <translation>Zavřít (%1)</translation>
    </message>
    <message>
        <location filename="../src/alert.cpp" line="177"/>
        <source>Collapse</source>
        <translation>Složit</translation>
    </message>
    <message>
        <location filename="../src/alert.cpp" line="181"/>
        <source>Expand</source>
        <translation>Rozbalit</translation>
    </message>
</context>
<context>
    <name>AlertLayer</name>
    <message>
        <location filename="../src/alert_layer.cpp" line="37"/>
        <source>Dismiss Alert</source>
        <translation>Odvolat poplach</translation>
    </message>
    <message>
        <location filename="../src/alert_layer.cpp" line="38"/>
        <source>Ctrl+D</source>
        <translation>Ctrl+D</translation>
    </message>
</context>
<context>
    <name>DailyProgress</name>
    <message numerus="yes">
        <location filename="../src/daily_progress.cpp" line="503"/>
        <source>%1% of %Ln minute(s)</source>
        <translation>
            <numerusform>%1% z %Ln minut</numerusform>
            <numerusform>%1% z %Ln minut</numerusform>
            <numerusform>%1% z %Ln minut</numerusform>
        </translation>
    </message>
    <message numerus="yes">
        <location filename="../src/daily_progress.cpp" line="505"/>
        <source>%1% of %Ln word(s)</source>
        <translation>
            <numerusform>%1% z %Ln slov</numerusform>
            <numerusform>%1% z %Ln slov</numerusform>
            <numerusform>%1% z %Ln slov</numerusform>
        </translation>
    </message>
    <message numerus="yes">
        <location filename="../src/daily_progress.cpp" line="507"/>
        <source>%Ln word(s)</source>
        <translation>
            <numerusform>%Ln slovo</numerusform>
            <numerusform>%Ln slova</numerusform>
            <numerusform>%Ln slov</numerusform>
        </translation>
    </message>
    <message numerus="yes">
        <location filename="../src/daily_progress.cpp" line="509"/>
        <source>%Ln minute(s)</source>
        <translation>
            <numerusform>%Ln minuta</numerusform>
            <numerusform>%Ln minuty</numerusform>
            <numerusform>%Ln minut</numerusform>
        </translation>
    </message>
    <message>
        <location filename="../src/daily_progress.cpp" line="511"/>
        <source>0%</source>
        <translation>0%</translation>
    </message>
</context>
<context>
    <name>DailyProgressDialog</name>
    <message>
        <location filename="../src/daily_progress_dialog.cpp" line="146"/>
        <source>Daily Progress</source>
        <translation>Denní postup</translation>
    </message>
    <message>
        <location filename="../src/daily_progress_dialog.cpp" line="282"/>
        <source>Longest streak</source>
        <translation>Nejdelší proužek</translation>
    </message>
    <message>
        <location filename="../src/daily_progress_dialog.cpp" line="285"/>
        <source>Current streak</source>
        <translation>Nynější proužek</translation>
    </message>
    <message>
        <location filename="../src/daily_progress_dialog.cpp" line="298"/>
        <source>N/A</source>
        <translation>Nedostupné</translation>
    </message>
    <message numerus="yes">
        <location filename="../src/daily_progress_dialog.cpp" line="303"/>
        <source>%n day(s)</source>
        <translation>
            <numerusform>%n den</numerusform>
            <numerusform>%n dny</numerusform>
            <numerusform>%n dnů</numerusform>
        </translation>
    </message>
    <message>
        <location filename="../src/daily_progress_dialog.cpp" line="304"/>
        <source>%1 &amp;ndash; %2</source>
        <translation>%1 &amp;ndash; %2</translation>
    </message>
</context>
<context>
    <name>DailyProgressLabel</name>
    <message>
        <location filename="../src/daily_progress_label.cpp" line="30"/>
        <location filename="../src/daily_progress_label.cpp" line="47"/>
        <source>%1% of daily goal</source>
        <translation>%1% z denního cíle</translation>
    </message>
</context>
<context>
    <name>DictionaryDialog</name>
    <message>
        <location filename="../src/spelling/dictionary_dialog.cpp" line="36"/>
        <source>Set Language</source>
        <translation>Nastavit jazyk</translation>
    </message>
</context>
<context>
    <name>Document</name>
    <message>
        <location filename="../src/document.cpp" line="425"/>
        <source>(Untitled %1)</source>
        <translation>(Bez názvu %1)</translation>
    </message>
    <message>
        <location filename="../src/document.cpp" line="428"/>
        <source>%1 (Read-Only)</source>
        <translation>%1 (pouze pro čtení)</translation>
    </message>
    <message>
        <location filename="../src/document.cpp" line="492"/>
        <location filename="../src/document.cpp" line="517"/>
        <location filename="../src/document.cpp" line="553"/>
        <location filename="../src/document.cpp" line="559"/>
        <source>Sorry</source>
        <translation>Promiňte</translation>
    </message>
    <message>
        <location filename="../src/document.cpp" line="492"/>
        <source>Unable to save &apos;%1&apos;.</source>
        <translation>Nelze uložit &apos;%1&apos;.</translation>
    </message>
    <message>
        <location filename="../src/document.cpp" line="507"/>
        <source>Save File As</source>
        <translation>Uložit soubor jako</translation>
    </message>
    <message>
        <location filename="../src/document.cpp" line="517"/>
        <location filename="../src/document.cpp" line="553"/>
        <source>Unable to overwrite &apos;%1&apos;.</source>
        <translation>Nelze přepsat &apos;%1&apos;.</translation>
    </message>
    <message>
        <location filename="../src/document.cpp" line="546"/>
        <source>Rename File</source>
        <translation>Přejmenovat soubor</translation>
    </message>
    <message>
        <location filename="../src/document.cpp" line="559"/>
        <source>Unable to rename &apos;%1&apos;.</source>
        <translation>Nelze přejmenovat &apos;%1&apos;.</translation>
    </message>
    <message>
        <location filename="../src/document.cpp" line="585"/>
        <source>Reload File?</source>
        <translation>Nahrát soubor znovu?</translation>
    </message>
    <message>
        <location filename="../src/document.cpp" line="586"/>
        <source>Reload the file &apos;%1&apos; from disk?</source>
        <translation>Nahrát soubor &apos;%1&apos; znovu z disku?</translation>
    </message>
    <message>
        <location filename="../src/document.cpp" line="587"/>
        <source>All unsaved changes will be lost.</source>
        <translation>Všechny neuložené změny budou ztraceny.</translation>
    </message>
    <message>
        <location filename="../src/document.cpp" line="589"/>
        <source>Reload</source>
        <translation>Nahrát znovu</translation>
    </message>
    <message>
        <location filename="../src/document.cpp" line="1321"/>
        <source>Untitled %1</source>
        <translation>Bez názvu %1</translation>
    </message>
    <message>
        <location filename="../src/document.cpp" line="1375"/>
        <source>Question</source>
        <translation>Otázka</translation>
    </message>
    <message>
        <location filename="../src/document.cpp" line="1376"/>
        <source>Saving as plain text will discard all formatting. Discard formatting?</source>
        <translation>Uložení v prostém textu zahodí všechno formátování. Zahodit formátování?</translation>
    </message>
</context>
<context>
    <name>DocumentWatcher</name>
    <message>
        <location filename="../src/document_watcher.cpp" line="191"/>
        <source>File Changed</source>
        <translation>Soubor změněn</translation>
    </message>
    <message>
        <location filename="../src/document_watcher.cpp" line="192"/>
        <source>The file &apos;%1&apos; was changed by another program.</source>
        <translation>Soubor &apos;%1&apos; byl změněn jiným programem.</translation>
    </message>
    <message>
        <location filename="../src/document_watcher.cpp" line="193"/>
        <source>Do you want to reload the file?</source>
        <translation>Chcete soubor nahrát znovu?</translation>
    </message>
    <message>
        <location filename="../src/document_watcher.cpp" line="195"/>
        <source>Reload</source>
        <translation>Nahrát znovu</translation>
    </message>
    <message>
        <location filename="../src/document_watcher.cpp" line="200"/>
        <source>Ignore</source>
        <translation>Přehlížet</translation>
    </message>
    <message>
        <location filename="../src/document_watcher.cpp" line="211"/>
        <source>File Deleted</source>
        <translation>Soubor smazán</translation>
    </message>
    <message>
        <location filename="../src/document_watcher.cpp" line="212"/>
        <source>The file %1 was deleted by another program.</source>
        <translation>Soubor %1 byl smazán jiným programem.</translation>
    </message>
    <message>
        <location filename="../src/document_watcher.cpp" line="213"/>
        <source>Do you want to save or close the file?</source>
        <translation>Chcete soubor uložit nebo zavřít?</translation>
    </message>
</context>
<context>
    <name>DocxReader</name>
    <message>
        <location filename="../src/fileformats/docx_reader.cpp" line="94"/>
        <source>Unable to open archive.</source>
        <translation>Nelze otevřít archiv.</translation>
    </message>
</context>
<context>
    <name>FindDialog</name>
    <message>
        <location filename="../src/find_dialog.cpp" line="47"/>
        <source>Search for:</source>
        <translation>Hledat:</translation>
    </message>
    <message>
        <location filename="../src/find_dialog.cpp" line="49"/>
        <source>Replace with:</source>
        <translation>Nahradit:</translation>
    </message>
    <message>
        <location filename="../src/find_dialog.cpp" line="53"/>
        <source>Ignore case</source>
        <translation>Nevšímat si velikosti písmen</translation>
    </message>
    <message>
        <location filename="../src/find_dialog.cpp" line="54"/>
        <source>Whole words only</source>
        <translation>Pouze celá slova</translation>
    </message>
    <message>
        <location filename="../src/find_dialog.cpp" line="55"/>
        <source>Regular expressions</source>
        <translation>Regulární výrazy</translation>
    </message>
    <message>
        <location filename="../src/find_dialog.cpp" line="58"/>
        <source>Search up</source>
        <translation>Hledat nahoru</translation>
    </message>
    <message>
        <location filename="../src/find_dialog.cpp" line="59"/>
        <source>Search down</source>
        <translation>Hledat dolů</translation>
    </message>
    <message>
        <location filename="../src/find_dialog.cpp" line="66"/>
        <source>&amp;Find</source>
        <translation>&amp;Hledat</translation>
    </message>
    <message>
        <location filename="../src/find_dialog.cpp" line="70"/>
        <source>&amp;Replace</source>
        <translation>&amp;Nahradit</translation>
    </message>
    <message>
        <location filename="../src/find_dialog.cpp" line="74"/>
        <source>Replace &amp;All</source>
        <translation>Nahradit &amp;vše</translation>
    </message>
    <message>
        <location filename="../src/find_dialog.cpp" line="151"/>
        <source>Find</source>
        <translation>Najít</translation>
    </message>
    <message>
        <location filename="../src/find_dialog.cpp" line="159"/>
        <source>Replace</source>
        <translation>Nahradit</translation>
    </message>
    <message numerus="yes">
        <location filename="../src/find_dialog.cpp" line="275"/>
        <source>Replace %n instance(s)?</source>
        <translation>
            <numerusform>Nahradit jeden případ?</numerusform>
            <numerusform>Nahradit %n případy?</numerusform>
            <numerusform>Nahradit %n případů?</numerusform>
        </translation>
    </message>
    <message>
        <location filename="../src/find_dialog.cpp" line="275"/>
        <source>Question</source>
        <translation>Otázka</translation>
    </message>
    <message>
        <location filename="../src/find_dialog.cpp" line="279"/>
        <location filename="../src/find_dialog.cpp" line="354"/>
        <source>Sorry</source>
        <translation>Promiňte</translation>
    </message>
    <message>
        <location filename="../src/find_dialog.cpp" line="279"/>
        <location filename="../src/find_dialog.cpp" line="354"/>
        <source>Phrase not found.</source>
        <translation>Slovní spojení nebylo nenalezeno.</translation>
    </message>
</context>
<context>
    <name>FormatManager</name>
    <message>
        <location filename="../src/fileformats/format_manager.cpp" line="71"/>
        <source>OpenDocument Text</source>
        <translation>OpenDocument Text</translation>
    </message>
    <message>
        <location filename="../src/fileformats/format_manager.cpp" line="73"/>
        <source>Office Open XML</source>
        <translation>Office Open XML</translation>
    </message>
    <message>
        <location filename="../src/fileformats/format_manager.cpp" line="75"/>
        <source>Rich Text Format</source>
        <translation>Rich Text Format</translation>
    </message>
    <message>
        <location filename="../src/fileformats/format_manager.cpp" line="77"/>
        <source>Plain Text</source>
        <translation>Prostý text</translation>
    </message>
    <message>
        <location filename="../src/fileformats/format_manager.cpp" line="92"/>
        <source>All Files</source>
        <translation>Všechny soubory</translation>
    </message>
    <message>
        <location filename="../src/fileformats/format_manager.cpp" line="106"/>
        <source>All Supported Files</source>
        <translation>Všechny podporované soubory</translation>
    </message>
</context>
<context>
    <name>Highlighter</name>
    <message>
        <location filename="../src/spelling/highlighter.cpp" line="54"/>
        <source>Add</source>
        <translation>Přidat</translation>
    </message>
    <message>
        <location filename="../src/spelling/highlighter.cpp" line="55"/>
        <source>Check Spelling...</source>
        <translation>Ověření pravopisu...</translation>
    </message>
    <message>
        <location filename="../src/spelling/highlighter.cpp" line="129"/>
        <source>(No suggestions found)</source>
        <translation>(Nebyly nalezeny žádné návrhy)</translation>
    </message>
</context>
<context>
    <name>ImageButton</name>
    <message>
        <location filename="../src/image_button.cpp" line="100"/>
        <source>Open Image</source>
        <translation>Otevřít obrázek</translation>
    </message>
    <message>
        <location filename="../src/image_button.cpp" line="100"/>
        <source>Images(%1)</source>
        <translation>Obrázky (%1)</translation>
    </message>
</context>
<context>
    <name>LocaleDialog</name>
    <message>
        <location filename="../src/locale_dialog.cpp" line="51"/>
        <source>Select application language:</source>
        <translation>Vybrat jazyk programu:</translation>
    </message>
    <message>
        <location filename="../src/locale_dialog.cpp" line="54"/>
        <source>&lt;System Language&gt;</source>
        <translation>&lt;Jazyk systému&gt;</translation>
    </message>
    <message>
        <location filename="../src/locale_dialog.cpp" line="189"/>
        <source>Note</source>
        <translation>Poznámka</translation>
    </message>
    <message>
        <location filename="../src/locale_dialog.cpp" line="189"/>
        <source>Please restart this application for the change in language to take effect.</source>
        <translation>Spusťte program znovu, aby se změna jazyka projevila.</translation>
    </message>
</context>
<context>
    <name>OdtReader</name>
    <message>
        <location filename="../src/fileformats/odt_reader.cpp" line="68"/>
        <source>Unable to open archive.</source>
        <translation>Nelze otevřít archiv.</translation>
    </message>
</context>
<context>
    <name>PreferencesDialog</name>
    <message>
        <location filename="../src/preferences_dialog.cpp" line="109"/>
        <source>Preferences</source>
        <translation>Nastavení</translation>
    </message>
    <message>
        <location filename="../src/preferences_dialog.cpp" line="112"/>
        <source>General</source>
        <translation>Obecné</translation>
    </message>
    <message>
        <location filename="../src/preferences_dialog.cpp" line="114"/>
        <source>Statistics</source>
        <translation>Statistika</translation>
    </message>
    <message>
        <location filename="../src/preferences_dialog.cpp" line="116"/>
        <source>Toolbar</source>
        <translation>Nástrojový pruh</translation>
    </message>
    <message>
        <location filename="../src/preferences_dialog.cpp" line="115"/>
        <source>Spell Checking</source>
        <translation>Správné psaní</translation>
    </message>
    <message>
        <location filename="../src/preferences_dialog.cpp" line="453"/>
        <source>Select Dictionary</source>
        <translation>Vybrat slovník</translation>
    </message>
    <message>
        <location filename="../src/preferences_dialog.cpp" line="467"/>
        <location filename="../src/preferences_dialog.cpp" line="570"/>
        <source>Sorry</source>
        <translation>Promiňte</translation>
    </message>
    <message>
        <location filename="../src/preferences_dialog.cpp" line="467"/>
        <source>Unable to open archive.</source>
        <translation>Nelze otevřít archiv.</translation>
    </message>
    <message>
        <location filename="../src/preferences_dialog.cpp" line="570"/>
        <source>The archive does not contain a usable dictionary.</source>
        <translation>Archiv neobsahuje použitelný slovník.</translation>
    </message>
    <message>
        <location filename="../src/preferences_dialog.cpp" line="256"/>
        <location filename="../src/preferences_dialog.cpp" line="395"/>
        <location filename="../src/preferences_dialog.cpp" line="558"/>
        <source>Question</source>
        <translation>Otázka</translation>
    </message>
    <message>
        <location filename="../src/preferences_dialog.cpp" line="117"/>
        <source>Shortcuts</source>
        <translation>Zkratky</translation>
    </message>
    <message>
        <location filename="../src/preferences_dialog.cpp" line="257"/>
        <source>One or more shortcuts conflict. Do you wish to proceed?</source>
        <translation>Střet jedné nebo více zkratek. Chcete pokračovat?</translation>
    </message>
    <message>
        <location filename="../src/preferences_dialog.cpp" line="558"/>
        <source>The dictionary &quot;%1&quot; already exists. Do you want to replace it?</source>
        <translation>Slovník &quot;%1&quot; již existuje. Chcete jej nahradit?</translation>
    </message>
    <message>
        <location filename="../src/preferences_dialog.cpp" line="113"/>
        <source>Daily Goal</source>
        <translation>Denní cíl</translation>
    </message>
    <message>
        <location filename="../src/preferences_dialog.cpp" line="793"/>
        <source>None</source>
        <translation>Žádný</translation>
    </message>
    <message>
        <location filename="../src/preferences_dialog.cpp" line="795"/>
        <source>Minutes:</source>
        <translation>Minut:</translation>
    </message>
    <message>
        <location filename="../src/preferences_dialog.cpp" line="802"/>
        <location filename="../src/preferences_dialog.cpp" line="912"/>
        <source>Words:</source>
        <translation>Slov:</translation>
    </message>
    <message>
        <location filename="../src/preferences_dialog.cpp" line="705"/>
        <source>Editing</source>
        <translation>Úpravy</translation>
    </message>
    <message>
        <location filename="../src/preferences_dialog.cpp" line="707"/>
        <source>Always vertically center</source>
        <translation>Umístit vždy svisle do středu</translation>
    </message>
    <message>
        <location filename="../src/preferences_dialog.cpp" line="708"/>
        <source>Block insertion cursor</source>
        <translation>Ukazatel vkládání bloku</translation>
    </message>
    <message>
        <location filename="../src/preferences_dialog.cpp" line="709"/>
        <source>Smooth fonts</source>
        <translation>Vyhlazená písma</translation>
    </message>
    <message>
        <location filename="../src/preferences_dialog.cpp" line="710"/>
        <source>Typewriter sounds</source>
        <translation>Zvuky psacího stroje</translation>
    </message>
    <message>
        <location filename="../src/preferences_dialog.cpp" line="712"/>
        <source>Smart quotes:</source>
        <translation>Chytré uvozovky:</translation>
    </message>
    <message>
        <location filename="../src/preferences_dialog.cpp" line="719"/>
        <source>Double</source>
        <translation>dvojité</translation>
    </message>
    <message>
        <location filename="../src/preferences_dialog.cpp" line="720"/>
        <source>Single</source>
        <translation>jednoduché</translation>
    </message>
    <message>
        <location filename="../src/preferences_dialog.cpp" line="741"/>
        <source>Scenes</source>
        <translation>Scény</translation>
    </message>
    <message>
        <location filename="../src/preferences_dialog.cpp" line="748"/>
        <source>Divider:</source>
        <translation>Oddělovač</translation>
    </message>
    <message>
        <location filename="../src/preferences_dialog.cpp" line="751"/>
        <source>Saving</source>
        <translation>Ukládání</translation>
    </message>
    <message>
        <location filename="../src/preferences_dialog.cpp" line="753"/>
        <source>Automatically save changes</source>
        <translation>Automaticky uložit změny</translation>
    </message>
    <message>
        <location filename="../src/preferences_dialog.cpp" line="754"/>
        <source>Remember cursor position</source>
        <translation>Zapamatovat si polohu ukazatele</translation>
    </message>
    <message>
        <location filename="../src/preferences_dialog.cpp" line="872"/>
        <source>Word count</source>
        <translation>Počet slov</translation>
    </message>
    <message>
        <location filename="../src/preferences_dialog.cpp" line="873"/>
        <source>Page count</source>
        <translation>Počet stran</translation>
    </message>
    <message>
        <location filename="../src/preferences_dialog.cpp" line="874"/>
        <source>Paragraph count</source>
        <translation>Počet odstavců</translation>
    </message>
    <message>
        <location filename="../src/preferences_dialog.cpp" line="875"/>
        <source>Character count</source>
        <translation>Počet znaků</translation>
    </message>
    <message>
        <location filename="../src/preferences_dialog.cpp" line="898"/>
        <source>Characters:</source>
        <translation>Znaků:</translation>
    </message>
    <message>
        <location filename="../src/preferences_dialog.cpp" line="905"/>
        <source>Paragraphs:</source>
        <translation>Odstavců:</translation>
    </message>
    <message>
        <location filename="../src/preferences_dialog.cpp" line="884"/>
        <source>Word Count Algorithm</source>
        <translation>Algoritmus pro počítání slov</translation>
    </message>
    <message>
        <location filename="../src/preferences_dialog.cpp" line="396"/>
        <source>Reset daily progress for today to zero?</source>
        <translation>Nastavit denní postup pro dnešek znovu na nulu?</translation>
    </message>
    <message>
        <location filename="../src/preferences_dialog.cpp" line="755"/>
        <source>Write byte order mark in plain text files</source>
        <translation>Zapsat značku pro pořadí bytů (BOM) do souborů prostého textu</translation>
    </message>
    <message>
        <location filename="../src/preferences_dialog.cpp" line="757"/>
        <source>Default format:</source>
        <translation>Výchozí formát:</translation>
    </message>
    <message>
        <location filename="../src/preferences_dialog.cpp" line="818"/>
        <source>Reset Today</source>
        <translation>Vynulovat dnešek</translation>
    </message>
    <message>
        <location filename="../src/preferences_dialog.cpp" line="831"/>
        <source>History</source>
        <translation>Historie</translation>
    </message>
    <message>
        <location filename="../src/preferences_dialog.cpp" line="833"/>
        <source>Remember history</source>
        <translation>Zapamatovat si historii</translation>
    </message>
    <message>
        <location filename="../src/preferences_dialog.cpp" line="836"/>
        <source>Show streaks</source>
        <translation>Ukázat proužky</translation>
    </message>
    <message>
        <location filename="../src/preferences_dialog.cpp" line="851"/>
        <source>Minimum progress for streaks:</source>
        <translation>Nejmenší postup pro proužky:</translation>
    </message>
    <message>
        <location filename="../src/preferences_dialog.cpp" line="886"/>
        <source>Detect word boundaries</source>
        <translation>Zjistit hranice slov</translation>
    </message>
    <message>
        <location filename="../src/preferences_dialog.cpp" line="887"/>
        <source>Divide character count by six</source>
        <translation>Vydělit počet znaků šesti</translation>
    </message>
    <message>
        <location filename="../src/preferences_dialog.cpp" line="888"/>
        <source>Count each letter as a word</source>
        <translation>Počítat každé písmeno za slovo</translation>
    </message>
    <message>
        <location filename="../src/preferences_dialog.cpp" line="896"/>
        <source>Page Count Algorithm</source>
        <translation>Algoritmus pro počítání stran</translation>
    </message>
    <message>
        <location filename="../src/preferences_dialog.cpp" line="1039"/>
        <source>Style</source>
        <translation>Styl</translation>
    </message>
    <message>
        <location filename="../src/preferences_dialog.cpp" line="1042"/>
        <source>Icons Only</source>
        <translation>Pouze ikony</translation>
    </message>
    <message>
        <location filename="../src/preferences_dialog.cpp" line="1043"/>
        <source>Text Only</source>
        <translation>Pouze text</translation>
    </message>
    <message>
        <location filename="../src/preferences_dialog.cpp" line="1044"/>
        <source>Text Alongside Icons</source>
        <translation>Text vedle ikon</translation>
    </message>
    <message>
        <location filename="../src/preferences_dialog.cpp" line="1045"/>
        <source>Text Under Icons</source>
        <translation>Text pod ikonami</translation>
    </message>
    <message>
        <location filename="../src/preferences_dialog.cpp" line="1049"/>
        <source>Text Position:</source>
        <translation>Poloha textu:</translation>
    </message>
    <message>
        <location filename="../src/preferences_dialog.cpp" line="1052"/>
        <source>Actions</source>
        <translation>Činnosti</translation>
    </message>
    <message>
        <location filename="../src/preferences_dialog.cpp" line="1068"/>
        <source>Move Up</source>
        <translation>Posunout nahoru</translation>
    </message>
    <message>
        <location filename="../src/preferences_dialog.cpp" line="1070"/>
        <source>Move Down</source>
        <translation>Posunout dolů</translation>
    </message>
    <message>
        <location filename="../src/preferences_dialog.cpp" line="1072"/>
        <source>Add Separator</source>
        <translation>Přidat oddělovač</translation>
    </message>
    <message>
        <location filename="../src/preferences_dialog.cpp" line="1106"/>
        <source>Command</source>
        <translation>Příkaz</translation>
    </message>
    <message>
        <location filename="../src/preferences_dialog.cpp" line="1106"/>
        <source>Shortcut</source>
        <translation>Zkratka</translation>
    </message>
    <message>
        <location filename="../src/preferences_dialog.cpp" line="1106"/>
        <source>Action</source>
        <translation>Činnost</translation>
    </message>
    <message>
        <location filename="../src/preferences_dialog.cpp" line="959"/>
        <source>Check spelling as you type</source>
        <translation>Ověřování pravopisu během psaní</translation>
    </message>
    <message>
        <location filename="../src/preferences_dialog.cpp" line="960"/>
        <source>Ignore words in UPPERCASE</source>
        <translation>Nevšímat si slov psaných VELKÝMI PÍSMENY</translation>
    </message>
    <message>
        <location filename="../src/preferences_dialog.cpp" line="961"/>
        <source>Ignore words with numbers</source>
        <translation>Nevšímat si slov s čísly</translation>
    </message>
    <message>
        <location filename="../src/preferences_dialog.cpp" line="974"/>
        <source>Language</source>
        <translation>Jazyk</translation>
    </message>
    <message>
        <location filename="../src/preferences_dialog.cpp" line="978"/>
        <location filename="../src/preferences_dialog.cpp" line="999"/>
        <source>Add</source>
        <translation>Přidat</translation>
    </message>
    <message>
        <location filename="../src/preferences_dialog.cpp" line="1011"/>
        <source>Remove</source>
        <translation>Odstranit</translation>
    </message>
    <message>
        <location filename="../src/preferences_dialog.cpp" line="994"/>
        <source>Personal Dictionary</source>
        <translation>Osobní slovník</translation>
    </message>
</context>
<context>
    <name>RtfReader</name>
    <message>
        <location filename="../src/fileformats/rtf_reader.cpp" line="209"/>
        <location filename="../src/fileformats/rtf_reader.cpp" line="213"/>
        <source>Not a supported RTF file.</source>
        <translation>Není podporovaným souborem RTF.</translation>
    </message>
</context>
<context>
    <name>RtfTokenizer</name>
    <message>
        <location filename="../src/fileformats/rtf_tokenizer.cpp" line="151"/>
        <source>Unexpectedly reached end of file.</source>
        <translation>Neočekávaně dosaženo konce souboru.</translation>
    </message>
</context>
<context>
    <name>SceneList</name>
    <message>
        <location filename="../src/scene_list.cpp" line="89"/>
        <source>Ctrl+Shift+Down</source>
        <translation>Ctrl+Shift+šipka dolů</translation>
    </message>
    <message>
        <location filename="../src/scene_list.cpp" line="94"/>
        <source>Move Scenes Up</source>
        <translation>Přesunout scény nahoru</translation>
    </message>
    <message>
        <location filename="../src/scene_list.cpp" line="95"/>
        <source>Ctrl+Shift+Up</source>
        <translation>Ctrl+Shift+šipka nahoru</translation>
    </message>
    <message>
        <location filename="../src/scene_list.cpp" line="115"/>
        <source>Toggle Scene List</source>
        <translation>Přepnout seznam scén</translation>
    </message>
    <message>
        <location filename="../src/scene_list.cpp" line="116"/>
        <source>Shift+F4</source>
        <translation>Shift+F4</translation>
    </message>
    <message>
        <location filename="../src/scene_list.cpp" line="399"/>
        <source>Show scene list (%1)</source>
        <translation>Ukázat seznam scén (%1)</translation>
    </message>
    <message>
        <location filename="../src/scene_list.cpp" line="400"/>
        <source>Hide scene list (%1)</source>
        <translation>Skrýt seznam scén (%1)</translation>
    </message>
    <message>
        <location filename="../src/scene_list.cpp" line="147"/>
        <source>Filter</source>
        <translation>Filtr</translation>
    </message>
    <message>
        <location filename="../src/scene_list.cpp" line="88"/>
        <source>Move Scenes Down</source>
        <translation>Přesunout scény dolů</translation>
    </message>
    <message>
        <location filename="../src/scene_list.cpp" line="155"/>
        <source>Resize scene list</source>
        <translation>Změnit velikost seznamu scén</translation>
    </message>
</context>
<context>
    <name>Session</name>
    <message>
        <location filename="../src/session.cpp" line="43"/>
        <location filename="../src/session_manager.cpp" line="57"/>
        <location filename="../src/session_manager.cpp" line="428"/>
        <location filename="../src/session_manager.cpp" line="451"/>
        <location filename="../src/session_manager.cpp" line="460"/>
        <location filename="../src/session_manager.cpp" line="461"/>
        <source>Default</source>
        <translation>Výchozí</translation>
    </message>
</context>
<context>
    <name>SessionManager</name>
    <message>
        <location filename="../src/session_manager.cpp" line="52"/>
        <source>Manage Sessions</source>
        <translation>Spravovat sezení</translation>
    </message>
    <message>
        <location filename="../src/session_manager.cpp" line="83"/>
        <source>S&amp;essions</source>
        <translation>S&amp;ezení</translation>
    </message>
    <message>
        <location filename="../src/session_manager.cpp" line="97"/>
        <source>New</source>
        <translation>Nové</translation>
    </message>
    <message>
        <location filename="../src/session_manager.cpp" line="100"/>
        <source>Duplicate</source>
        <translation>Zdvojit</translation>
    </message>
    <message>
        <location filename="../src/session_manager.cpp" line="103"/>
        <source>Rename</source>
        <translation>Přejmenovat</translation>
    </message>
    <message>
        <location filename="../src/session_manager.cpp" line="106"/>
        <source>Delete</source>
        <translation>Smazat</translation>
    </message>
    <message>
        <location filename="../src/session_manager.cpp" line="109"/>
        <source>Switch To</source>
        <translation>Přepnout na</translation>
    </message>
    <message>
        <location filename="../src/session_manager.cpp" line="220"/>
        <source>New Session</source>
        <translation>Nové sezení</translation>
    </message>
    <message>
        <location filename="../src/session_manager.cpp" line="279"/>
        <source>Duplicate Session</source>
        <translation>Zdvojit sezení</translation>
    </message>
    <message>
        <location filename="../src/session_manager.cpp" line="324"/>
        <source>Rename Session</source>
        <translation>Přejmenovat sezení</translation>
    </message>
    <message>
        <location filename="../src/session_manager.cpp" line="351"/>
        <source>Question</source>
        <translation>Otázka</translation>
    </message>
    <message>
        <location filename="../src/session_manager.cpp" line="351"/>
        <source>Delete selected session?</source>
        <translation>Smazat vybrané sezení?</translation>
    </message>
    <message>
        <location filename="../src/session_manager.cpp" line="423"/>
        <source>Session name:</source>
        <translation>Název sezení:</translation>
    </message>
    <message>
        <location filename="../src/session_manager.cpp" line="431"/>
        <source>Sorry</source>
        <translation>Promiňte</translation>
    </message>
    <message>
        <location filename="../src/session_manager.cpp" line="431"/>
        <source>The requested session name is already in use.</source>
        <translation>Požadovaný název sezení se již používá.</translation>
    </message>
    <message>
        <location filename="../src/session_manager.cpp" line="487"/>
        <source>&amp;New...</source>
        <translation>&amp;Nové...</translation>
    </message>
    <message>
        <location filename="../src/session_manager.cpp" line="487"/>
        <source>Ctrl+Shift+N</source>
        <translation>Ctrl+Shift+N</translation>
    </message>
    <message>
        <location filename="../src/session_manager.cpp" line="488"/>
        <source>&amp;Manage...</source>
        <translation>&amp;Spravovat...</translation>
    </message>
    <message>
        <location filename="../src/session_manager.cpp" line="488"/>
        <source>Ctrl+Shift+M</source>
        <translation>Ctrl+Shift+M</translation>
    </message>
</context>
<context>
    <name>ShortcutEdit</name>
    <message>
        <location filename="../src/shortcut_edit.cpp" line="126"/>
        <source>Clear</source>
        <translation>Smazat</translation>
    </message>
    <message>
        <location filename="../src/shortcut_edit.cpp" line="129"/>
        <source>Reset to Default</source>
        <translation>Nastavit znovu na výchozí</translation>
    </message>
    <message>
        <location filename="../src/preferences_dialog.cpp" line="1149"/>
        <location filename="../src/symbols_dialog.cpp" line="219"/>
        <source>Shortcut:</source>
        <translation>Zkratka:</translation>
    </message>
</context>
<context>
    <name>SmartQuote</name>
    <message>
        <location filename="../src/smart_quotes.cpp" line="150"/>
        <source>Replacing quotation marks...</source>
        <translation>Nahrazují se uvozovky...</translation>
    </message>
    <message>
        <location filename="../src/smart_quotes.cpp" line="151"/>
        <source>Please Wait</source>
        <translation>Počkejte, prosím</translation>
    </message>
</context>
<context>
    <name>SpellChecker</name>
    <message>
        <location filename="../src/spelling/spell_checker.cpp" line="134"/>
        <source>Check Spelling</source>
        <translation>Ověření pravopisu</translation>
    </message>
    <message>
        <location filename="../src/spelling/spell_checker.cpp" line="142"/>
        <source>&amp;Add</source>
        <translation>&amp;Přidat</translation>
    </message>
    <message>
        <location filename="../src/spelling/spell_checker.cpp" line="145"/>
        <source>&amp;Ignore</source>
        <translation>Pře&amp;hlížet</translation>
    </message>
    <message>
        <location filename="../src/spelling/spell_checker.cpp" line="148"/>
        <source>I&amp;gnore All</source>
        <translation>Přeh&amp;lížet vše</translation>
    </message>
    <message>
        <location filename="../src/spelling/spell_checker.cpp" line="153"/>
        <source>&amp;Change</source>
        <translation>&amp;Změnit</translation>
    </message>
    <message>
        <location filename="../src/spelling/spell_checker.cpp" line="156"/>
        <source>C&amp;hange All</source>
        <translation>Změ&amp;nit</translation>
    </message>
    <message>
        <location filename="../src/spelling/spell_checker.cpp" line="171"/>
        <source>Not in dictionary:</source>
        <translation>Ne ve slovníku:</translation>
    </message>
    <message>
        <location filename="../src/spelling/spell_checker.cpp" line="179"/>
        <source>Change to:</source>
        <translation>Změnit na:</translation>
    </message>
    <message>
        <location filename="../src/spelling/spell_checker.cpp" line="195"/>
        <source>Checking spelling...</source>
        <translation>Ověřuje se pravopis...</translation>
    </message>
    <message>
        <location filename="../src/spelling/spell_checker.cpp" line="195"/>
        <source>Cancel</source>
        <translation>Zrušit</translation>
    </message>
    <message>
        <location filename="../src/spelling/spell_checker.cpp" line="196"/>
        <source>Please wait</source>
        <translation>Počkejte, prosím</translation>
    </message>
    <message>
        <location filename="../src/spelling/spell_checker.cpp" line="223"/>
        <source>Continue checking at beginning of file?</source>
        <translation>Pokračovat v kontrole od začátku souboru?</translation>
    </message>
    <message>
        <location filename="../src/spelling/spell_checker.cpp" line="282"/>
        <source>Spell check complete.</source>
        <translation>Ověření správného psaní je hotovo.</translation>
    </message>
</context>
<context>
    <name>SymbolsDialog</name>
    <message>
        <location filename="../src/symbols_dialog.cpp" line="96"/>
        <source>Symbols</source>
        <translation>Symboly</translation>
    </message>
    <message>
        <location filename="../src/symbols_dialog.cpp" line="103"/>
        <source>Recently used symbols</source>
        <translation>Nedávno použité symboly</translation>
    </message>
    <message>
        <location filename="../src/symbols_dialog.cpp" line="133"/>
        <source>All symbols</source>
        <translation>Všechny symboly</translation>
    </message>
    <message>
        <location filename="../src/symbols_dialog.cpp" line="195"/>
        <source>Details</source>
        <translation>Podrobnosti</translation>
    </message>
    <message>
        <location filename="../src/symbols_dialog.cpp" line="221"/>
        <source>Name:</source>
        <translation>Název:</translation>
    </message>
    <message>
        <location filename="../src/symbols_dialog.cpp" line="231"/>
        <source>Insert</source>
        <translation>Vložit</translation>
    </message>
</context>
<context>
    <name>SymbolsModel</name>
    <message>
        <location filename="../src/symbols_model.cpp" line="107"/>
        <source>Blocks</source>
        <translation>Bloky</translation>
    </message>
    <message>
        <location filename="../src/symbols_model.cpp" line="107"/>
        <source>Scripts</source>
        <translation>Skripty</translation>
    </message>
</context>
<context>
    <name>Theme</name>
    <message>
        <location filename="../src/theme.cpp" line="103"/>
        <source>Untitled %1</source>
        <translation>Bez názvu %1</translation>
    </message>
</context>
<context>
    <name>ThemeDialog</name>
    <message>
        <location filename="../src/theme_dialog.cpp" line="103"/>
        <source>Name:</source>
        <translation>Název:</translation>
    </message>
    <message>
        <location filename="../src/theme_dialog.cpp" line="164"/>
        <source>No Image</source>
        <translation>Žádný obrázek</translation>
    </message>
    <message>
        <location filename="../src/theme_dialog.cpp" line="164"/>
        <source>Tiled</source>
        <translation>Vydlážděno</translation>
    </message>
    <message>
        <location filename="../src/theme_dialog.cpp" line="164"/>
        <location filename="../src/theme_dialog.cpp" line="196"/>
        <source>Centered</source>
        <translation>Vystředěno</translation>
    </message>
    <message>
        <location filename="../src/theme_dialog.cpp" line="164"/>
        <location filename="../src/theme_dialog.cpp" line="196"/>
        <source>Stretched</source>
        <translation>Roztaženo</translation>
    </message>
    <message>
        <location filename="../src/theme_dialog.cpp" line="164"/>
        <source>Scaled</source>
        <translation>Změněno měřítko</translation>
    </message>
    <message>
        <location filename="../src/theme_dialog.cpp" line="164"/>
        <source>Zoomed</source>
        <translation>Přiblíženo</translation>
    </message>
    <message>
        <location filename="../src/theme_dialog.cpp" line="211"/>
        <source>Opacity:</source>
        <translation>Neprůhlednost:</translation>
    </message>
    <message>
        <location filename="../src/theme_dialog.cpp" line="212"/>
        <source>Position:</source>
        <translation>Poloha:</translation>
    </message>
    <message>
        <location filename="../src/theme_dialog.cpp" line="213"/>
        <source>Width:</source>
        <translation>Šířka:</translation>
    </message>
    <message>
        <location filename="../src/theme_dialog.cpp" line="217"/>
        <source>Round Text Background Corners</source>
        <translation>Kulaté rohy pozadí textu</translation>
    </message>
    <message>
        <location filename="../src/theme_dialog.cpp" line="231"/>
        <location filename="../src/theme_dialog.cpp" line="249"/>
        <location filename="../src/theme_dialog.cpp" line="279"/>
        <source>Radius:</source>
        <translation>Poloměr:</translation>
    </message>
    <message>
        <location filename="../src/theme_dialog.cpp" line="235"/>
        <source>Blur Text Background</source>
        <translation>Rozmazané pozadí textu</translation>
    </message>
    <message>
        <location filename="../src/theme_dialog.cpp" line="253"/>
        <source>Text Background Drop Shadow</source>
        <translation>Stín pozadí textu</translation>
    </message>
    <message>
        <location filename="../src/theme_dialog.cpp" line="280"/>
        <source>Vertical Offset:</source>
        <translation>Svislý posun:</translation>
    </message>
    <message>
        <location filename="../src/theme_dialog.cpp" line="284"/>
        <source>Margins</source>
        <translation>Okraje</translation>
    </message>
    <message>
        <location filename="../src/theme_dialog.cpp" line="302"/>
        <source>Window:</source>
        <translation>Okno:</translation>
    </message>
    <message>
        <location filename="../src/theme_dialog.cpp" line="303"/>
        <source>Page:</source>
        <translation>Strana:</translation>
    </message>
    <message>
        <location filename="../src/theme_dialog.cpp" line="361"/>
        <source>Indent first line</source>
        <translation>Odsadit první řádek</translation>
    </message>
    <message>
        <location filename="../src/theme_dialog.cpp" line="368"/>
        <source>Above:</source>
        <translation>Nad:</translation>
    </message>
    <message>
        <location filename="../src/theme_dialog.cpp" line="369"/>
        <source>Below:</source>
        <translation>Pod:</translation>
    </message>
    <message>
        <location filename="../src/theme_dialog.cpp" line="160"/>
        <source>Remove</source>
        <translation>Odstranit</translation>
    </message>
    <message>
        <location filename="../src/theme_dialog.cpp" line="93"/>
        <source>Edit Theme</source>
        <translation>Upravit vzhled</translation>
    </message>
    <message>
        <location filename="../src/theme_dialog.cpp" line="150"/>
        <source>Window Background</source>
        <translation>Pozadí okna</translation>
    </message>
    <message>
        <location filename="../src/theme_dialog.cpp" line="178"/>
        <location filename="../src/theme_dialog.cpp" line="332"/>
        <source>Type:</source>
        <translation>Typ:</translation>
    </message>
    <message>
        <location filename="../src/theme_dialog.cpp" line="144"/>
        <location filename="../src/theme_dialog.cpp" line="176"/>
        <location filename="../src/theme_dialog.cpp" line="210"/>
        <location filename="../src/theme_dialog.cpp" line="278"/>
        <source>Color:</source>
        <translation>Barva:</translation>
    </message>
    <message>
        <location filename="../src/theme_dialog.cpp" line="177"/>
        <source>Image:</source>
        <translation>Obrázek:</translation>
    </message>
    <message>
        <location filename="../src/theme_dialog.cpp" line="202"/>
        <location filename="../src/theme_dialog.cpp" line="224"/>
        <location filename="../src/theme_dialog.cpp" line="242"/>
        <location filename="../src/theme_dialog.cpp" line="264"/>
        <location filename="../src/theme_dialog.cpp" line="271"/>
        <location filename="../src/theme_dialog.cpp" line="288"/>
        <location filename="../src/theme_dialog.cpp" line="295"/>
        <location filename="../src/theme_dialog.cpp" line="344"/>
        <location filename="../src/theme_dialog.cpp" line="350"/>
        <location filename="../src/theme_dialog.cpp" line="356"/>
        <source> pixels</source>
        <translation> pixelů</translation>
    </message>
    <message>
        <location filename="../src/theme_dialog.cpp" line="196"/>
        <source>Left</source>
        <translation>Zarovnáno vlevo</translation>
    </message>
    <message>
        <location filename="../src/theme_dialog.cpp" line="182"/>
        <source>Text Background</source>
        <translation>Pozadí textu</translation>
    </message>
    <message>
        <location filename="../src/theme_dialog.cpp" line="196"/>
        <source>Right</source>
        <translation>Zarovnáno vpravo</translation>
    </message>
    <message>
        <location filename="../src/theme_dialog.cpp" line="116"/>
        <source>Text</source>
        <translation>Text</translation>
    </message>
    <message>
        <location filename="../src/theme_dialog.cpp" line="145"/>
        <source>Font:</source>
        <translation>Písmo:</translation>
    </message>
    <message>
        <location filename="../src/theme_dialog.cpp" line="146"/>
        <source>Misspelled:</source>
        <translation>Špatně napsáno:</translation>
    </message>
    <message>
        <location filename="../src/theme_dialog.cpp" line="307"/>
        <source>Line Spacing</source>
        <translation>Odstupy mezi řádky</translation>
    </message>
    <message>
        <location filename="../src/theme_dialog.cpp" line="311"/>
        <source>Single</source>
        <translation>Jednoduchý</translation>
    </message>
    <message>
        <location filename="../src/theme_dialog.cpp" line="311"/>
        <source>1.5 Lines</source>
        <translation>1.5 řádku</translation>
    </message>
    <message>
        <location filename="../src/theme_dialog.cpp" line="311"/>
        <source>Double</source>
        <translation>Dvojitý</translation>
    </message>
    <message>
        <location filename="../src/theme_dialog.cpp" line="311"/>
        <source>Proportional</source>
        <translation>Poměrný</translation>
    </message>
    <message>
        <location filename="../src/theme_dialog.cpp" line="333"/>
        <source>Height:</source>
        <translation>Výška:</translation>
    </message>
    <message>
        <location filename="../src/theme_dialog.cpp" line="341"/>
        <source>Paragraph Spacing</source>
        <translation>Odstupy mezi odstavci</translation>
    </message>
    <message>
        <location filename="../src/theme_dialog.cpp" line="367"/>
        <source>Tab Width:</source>
        <translation>Šířka zarážky:</translation>
    </message>
    <message>
        <location filename="../src/theme_manager.cpp" line="253"/>
        <source>New Theme</source>
        <translation>Nový vzhled</translation>
    </message>
</context>
<context>
    <name>ThemeManager</name>
    <message>
        <location filename="../src/theme_manager.cpp" line="78"/>
        <source>Themes</source>
        <translation>Vzhled</translation>
    </message>
    <message>
        <location filename="../src/theme_manager.cpp" line="92"/>
        <source>Default</source>
        <translation>Výchozí</translation>
    </message>
    <message>
        <location filename="../src/theme_manager.cpp" line="107"/>
        <source>Gentle Blues</source>
        <translation>Něžné blues</translation>
    </message>
    <message>
        <location filename="../src/theme_manager.cpp" line="108"/>
        <source>Old School</source>
        <translation>Stará škola</translation>
    </message>
    <message>
        <location filename="../src/theme_manager.cpp" line="109"/>
        <source>Space Dreams</source>
        <translation>Vesmírné sny</translation>
    </message>
    <message>
        <location filename="../src/theme_manager.cpp" line="110"/>
        <source>Writing Desk</source>
        <translation>Psací stůl</translation>
    </message>
    <message>
        <location filename="../src/theme_manager.cpp" line="113"/>
        <location filename="../src/theme_manager.cpp" line="174"/>
        <source>New</source>
        <translation>Nový</translation>
    </message>
    <message>
        <location filename="../src/theme_manager.cpp" line="117"/>
        <location filename="../src/theme_manager.cpp" line="178"/>
        <source>Duplicate</source>
        <translation>Zdvojit</translation>
    </message>
    <message>
        <location filename="../src/theme_manager.cpp" line="131"/>
        <source>Custom</source>
        <translation>Vlastní</translation>
    </message>
    <message>
        <location filename="../src/theme_manager.cpp" line="183"/>
        <source>Edit</source>
        <translation>Upravit</translation>
    </message>
    <message>
        <location filename="../src/theme_manager.cpp" line="188"/>
        <source>Delete</source>
        <translation>Smazat</translation>
    </message>
    <message>
        <location filename="../src/theme_manager.cpp" line="193"/>
        <source>Import</source>
        <translation>Zavést</translation>
    </message>
    <message>
        <location filename="../src/theme_manager.cpp" line="197"/>
        <source>Export</source>
        <translation>Vyvést</translation>
    </message>
    <message>
        <location filename="../src/theme_manager.cpp" line="311"/>
        <source>Question</source>
        <translation>Otázka</translation>
    </message>
    <message>
        <location filename="../src/theme_manager.cpp" line="311"/>
        <source>Delete theme &apos;%1&apos;?</source>
        <translation>Smazat vzhled &apos;%1&apos;?</translation>
    </message>
    <message>
        <location filename="../src/theme_manager.cpp" line="339"/>
        <location filename="../src/theme_manager.cpp" line="416"/>
        <source>Themes (%1)</source>
        <translation>Vzhledy (%1)</translation>
    </message>
    <message>
        <location filename="../src/theme_manager.cpp" line="339"/>
        <source>Import Theme</source>
        <translation>Zavést vzhled</translation>
    </message>
    <message>
        <location filename="../src/theme_manager.cpp" line="416"/>
        <source>Export Theme</source>
        <translation>Vyvést podobu</translation>
    </message>
</context>
<context>
    <name>Timer</name>
    <message>
        <location filename="../src/timer.cpp" line="255"/>
        <source>&lt;b&gt;%1&lt;/b&gt; - %2</source>
        <translation>&lt;b&gt;%1&lt;/b&gt; - %2</translation>
    </message>
    <message>
        <location filename="../src/timer.cpp" line="340"/>
        <source>Question</source>
        <translation>Otázka</translation>
    </message>
    <message>
        <location filename="../src/timer.cpp" line="340"/>
        <source>Delete timer?</source>
        <translation>Smazat časomíru?</translation>
    </message>
    <message>
        <location filename="../src/timer.cpp" line="355"/>
        <source>&lt;b&gt;Words:&lt;/b&gt; %L1</source>
        <translation>&lt;b&gt;Slova:&lt;/b&gt; %L1</translation>
    </message>
    <message>
        <location filename="../src/timer.cpp" line="356"/>
        <source>&lt;b&gt;Pages:&lt;/b&gt; %L1</source>
        <translation>&lt;b&gt;Strany:&lt;/b&gt; %L1</translation>
    </message>
    <message>
        <location filename="../src/timer.cpp" line="357"/>
        <source>&lt;b&gt;Paragraphs:&lt;/b&gt; %L1</source>
        <translation>&lt;b&gt;Odstavce:&lt;/b&gt; %L1</translation>
    </message>
    <message>
        <location filename="../src/timer.cpp" line="358"/>
        <source>&lt;b&gt;Characters:&lt;/b&gt; %L1 / %L2</source>
        <translation>&lt;b&gt;Znaky:&lt;/b&gt; %L1 / %L2</translation>
    </message>
    <message>
        <location filename="../src/timer.cpp" line="402"/>
        <source>Set Delay</source>
        <translation>Nastavit zpoždění</translation>
    </message>
    <message>
        <location filename="../src/timer.cpp" line="403"/>
        <source>Set Time</source>
        <translation>Nastavit čas</translation>
    </message>
    <message>
        <location filename="../src/timer.cpp" line="406"/>
        <source>Delay:</source>
        <translation>Zpoždění:</translation>
    </message>
    <message>
        <location filename="../src/timer.cpp" line="409"/>
        <source>Time:</source>
        <translation>Čas:</translation>
    </message>
    <message>
        <location filename="../src/timer.cpp" line="418"/>
        <source>HH:mm:ss</source>
        <translation>HH:mm:ss</translation>
    </message>
    <message>
        <location filename="../src/timer.cpp" line="431"/>
        <source>Alarm</source>
        <translation>Budík</translation>
    </message>
    <message>
        <location filename="../src/timer.cpp" line="444"/>
        <source>Type:</source>
        <translation>Typ:</translation>
    </message>
    <message>
        <location filename="../src/timer.cpp" line="448"/>
        <source>Memo:</source>
        <translation>Zpráva:</translation>
    </message>
    <message>
        <location filename="../src/timer.cpp" line="459"/>
        <source>Edit</source>
        <translation>Upravit</translation>
    </message>
    <message>
        <location filename="../src/timer.cpp" line="461"/>
        <source>Delete</source>
        <translation>Smazat</translation>
    </message>
</context>
<context>
    <name>TimerDisplay</name>
    <message>
        <location filename="../src/timer_display.cpp" line="150"/>
        <source>HH:mm:ss</source>
        <translation>HH:mm:ss</translation>
    </message>
    <message>
        <location filename="../src/timer_display.cpp" line="160"/>
        <source>No timers running</source>
        <translation>Neběží žádná časomíra</translation>
    </message>
</context>
<context>
    <name>TimerManager</name>
    <message>
        <location filename="../src/timer_manager.cpp" line="46"/>
        <source>Timers</source>
        <translation>Časomíry</translation>
    </message>
    <message>
        <location filename="../src/timer_manager.cpp" line="78"/>
        <source>New</source>
        <translation>Nová</translation>
    </message>
    <message>
        <location filename="../src/timer_manager.cpp" line="83"/>
        <source>Recent</source>
        <translation>Naposledy použitá</translation>
    </message>
    <message>
        <location filename="../src/timer_manager.cpp" line="123"/>
        <source>Question</source>
        <translation>Otázka</translation>
    </message>
    <message>
        <location filename="../src/timer_manager.cpp" line="123"/>
        <source>Cancel editing timers?</source>
        <translation>Zrušit časomíry pro úpravy?</translation>
    </message>
    <message>
        <location filename="../src/timer_manager.cpp" line="316"/>
        <source>+HH:mm:ss</source>
        <translation>+HH:mm:ss</translation>
    </message>
    <message>
        <location filename="../src/timer_manager.cpp" line="323"/>
        <source>%1 - %2</source>
        <translation>%1 - %2</translation>
    </message>
</context>
<context>
    <name>Window</name>
    <message>
        <location filename="../src/window.cpp" line="300"/>
        <source>Loading themes</source>
        <translation>Nahrávají se podoby</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="1146"/>
        <source>Loading sounds</source>
        <translation>Nahrávají se zvuky</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="309"/>
        <location filename="../src/window.cpp" line="1065"/>
        <source>Untitled</source>
        <translation>Bez názvu</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="682"/>
        <source>Open File</source>
        <translation>Otevřít soubor</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="864"/>
        <source>About FocusWriter</source>
        <translation>O programu FocusWriter</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="867"/>
        <source>FocusWriter</source>
        <translation>FocusWriter</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="868"/>
        <source>A simple fullscreen word processor</source>
        <translation>Jednoduchý celoobrazovkový editor textu</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="869"/>
        <source>Copyright &amp;copy; 2008-%1 Graeme Gott</source>
        <translation>Autorské právo &amp;copy; 2008-%1 Graeme Gott</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="870"/>
        <source>Released under the &lt;a href=%1&gt;GPL 3&lt;/a&gt; license</source>
        <translation>Vydáno pod licencí &lt;a href=%1&gt;GPL 3&lt;/a&gt;</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="871"/>
        <source>Uses icons from the &lt;a href=%1&gt;Oxygen&lt;/a&gt; icon theme</source>
        <translation>Používá ikony z motivu ikon &lt;a href=%1&gt;Oxygen&lt;/a&gt;</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="872"/>
        <source>Used under the &lt;a href=%1&gt;LGPL 3&lt;/a&gt; license</source>
        <translation>Vydáno pod licencí &lt;a href=%1&gt;LGPL 3&lt;/a&gt;</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="174"/>
        <location filename="../src/window.cpp" line="928"/>
        <source>Characters: %L1 / %L2</source>
        <translation>Znaky: %L1 / %L2</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="172"/>
        <location filename="../src/window.cpp" line="929"/>
        <source>Pages: %L1</source>
        <translation>Strany: %L1</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="173"/>
        <location filename="../src/window.cpp" line="930"/>
        <source>Paragraphs: %L1</source>
        <translation>Odstavce: %L1</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="171"/>
        <location filename="../src/window.cpp" line="931"/>
        <source>Words: %L1</source>
        <translation>Slova: %L1</translation>
    </message>
    <message>
        <location filename="../src/document.cpp" line="602"/>
        <location filename="../src/window.cpp" line="1020"/>
        <source>Opening %1</source>
        <translation>Otevírá se %1</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="332"/>
        <source>(Untitled %1)</source>
        <translation>(Bez názvu %1)</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="207"/>
        <source>List all documents</source>
        <translation>Vypsat všechny dokumenty</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="210"/>
        <source>Switch to Next Document</source>
        <translation>Přepnout na další dokument</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="216"/>
        <source>Switch to Previous Document</source>
        <translation>Přepnout na předchozí dokument</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="222"/>
        <source>Switch to First Document</source>
        <translation>Přepnout na první dokument</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="228"/>
        <source>Switch to Last Document</source>
        <translation>Přepnout na poslední dokument</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="236"/>
        <source>Switch to Document %1</source>
        <translation>Přepnout na dokument %1</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="296"/>
        <source>Loading settings</source>
        <translation>Nahrávají se nastavení</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="318"/>
        <source>Emergency cache is not writable.</source>
        <translation>Pohotovostní vyrovnávací paměť není zapisovatelná</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="338"/>
        <location filename="../src/window.cpp" line="1034"/>
        <source>Warning</source>
        <translation>Varování</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="339"/>
        <source>FocusWriter was not shut down cleanly.</source>
        <translation>FocusWriter nebyl vypnut čistě.</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="340"/>
        <source>Restore from the emergency cache?</source>
        <translation>Obnovit z pohotovostní vyrovnávací paměti?</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="467"/>
        <source>Some files could not be opened.</source>
        <translation>Některé soubory se nepodařilo otevřít.</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="470"/>
        <source>Some files were opened Read-Only.</source>
        <translation>Některé soubory byly otevřeny pouze pro čtení.</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="1035"/>
        <source>&apos;%1&apos; is newer than the cached copy.</source>
        <translation>&apos;%1&apos; je novější než kopie ve vyrovnávací paměti.</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="1036"/>
        <source>Overwrite newer file?</source>
        <translation>Přepsat novější soubor?</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="1121"/>
        <source>Save Changes?</source>
        <translation>Uložit změny?</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="1122"/>
        <source>Save changes to the file &apos;%1&apos; before closing?</source>
        <translation>Uložit změny do souboru &apos;%1&apos; před zavřením?</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="1123"/>
        <source>Your changes will be lost if you don&apos;t save them.</source>
        <translation>Vaše změny budou ztraceny, pokud je neuložíte.</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="1153"/>
        <source>Unable to load typewriter sounds.</source>
        <translation>Nelze nahrát zvuky psacího stroje.</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="1154"/>
        <source>Please make sure that SDL_mixer is installed.</source>
        <translation>Ujistěte se, prosím, že je nainstalován SDL_mixer.</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="1290"/>
        <source>&amp;File</source>
        <translation>&amp;Soubor</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="1291"/>
        <source>&amp;New</source>
        <translation>&amp;Nový</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="1292"/>
        <source>&amp;Open...</source>
        <translation>&amp;Otevřít...</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="1293"/>
        <source>Reloa&amp;d</source>
        <translation>Nahrát z&amp;novu</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="1295"/>
        <source>&amp;Save</source>
        <translation>&amp;Uložit</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="1297"/>
        <source>Save &amp;As...</source>
        <translation>Uložit &amp;jako...</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="1298"/>
        <source>&amp;Rename...</source>
        <translation>Pře&amp;jmenovat...</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="1300"/>
        <source>Save A&amp;ll</source>
        <translation>U&amp;ložit vše</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="1303"/>
        <source>Manage Sessions</source>
        <translation>Spravovat sezení</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="1305"/>
        <source>New Session</source>
        <translation>Nové sezení</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="1308"/>
        <source>&amp;Print...</source>
        <translation>&amp;Tisk...</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="1310"/>
        <source>&amp;Close</source>
        <translation>&amp;Zavřít</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="1311"/>
        <source>&amp;Quit</source>
        <translation>&amp;Ukončit</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="1311"/>
        <source>Ctrl+Q</source>
        <translation>Ctrl+Q</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="1315"/>
        <source>&amp;Edit</source>
        <translation>Úp&amp;ravy</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="1316"/>
        <source>&amp;Undo</source>
        <translation>&amp;Zpět</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="1319"/>
        <source>&amp;Redo</source>
        <translation>Zn&amp;ovu</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="1323"/>
        <source>Cu&amp;t</source>
        <translation>Vyj&amp;mout</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="1326"/>
        <source>&amp;Copy</source>
        <translation>&amp;Kopírovat</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="1329"/>
        <source>&amp;Paste</source>
        <translation>&amp;Vložit</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="1330"/>
        <source>Paste &amp;Unformatted</source>
        <translation>Vložit ne&amp;formátované</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="1330"/>
        <source>Ctrl+Shift+V</source>
        <translation>Ctrl+Shift+V</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="1332"/>
        <source>Select &amp;All</source>
        <translation>Vybrat &amp;vše</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="1333"/>
        <source>Select &amp;Scene</source>
        <translation>Vybrat &amp;scénu</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="1333"/>
        <source>Ctrl+Shift+A</source>
        <translation>Ctrl+Shift+A</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="1336"/>
        <source>Fo&amp;rmat</source>
        <translation>&amp;Formát</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="1338"/>
        <source>&amp;Bold</source>
        <translation>&amp;Tučné</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="1340"/>
        <source>&amp;Italic</source>
        <translation>&amp;Kurzíva</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="1342"/>
        <source>&amp;Underline</source>
        <translation>&amp;Podtržení</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="1344"/>
        <source>Stri&amp;kethrough</source>
        <translation>Přeškr&amp;tnutí</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="1344"/>
        <source>Ctrl+K</source>
        <translation>Ctrl+K</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="1346"/>
        <source>Sup&amp;erscript</source>
        <translation>&amp;Horní index</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="1346"/>
        <source>Ctrl+^</source>
        <translation>Ctrl+^</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="1348"/>
        <source>&amp;Subscript</source>
        <translation>&amp;Dolní index</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="1348"/>
        <source>Ctrl+_</source>
        <translation>Ctrl+_</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="1352"/>
        <source>Align &amp;Left</source>
        <translation>Zarovnat &amp;vlevo</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="1352"/>
        <source>Ctrl+{</source>
        <translation>Ctrl+{</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="1354"/>
        <source>Align &amp;Center</source>
        <translation>Zarovnat na &amp;střed</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="1354"/>
        <source>Ctrl+|</source>
        <translation>Ctrl+|</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="1356"/>
        <source>Align &amp;Right</source>
        <translation>Zarovnat vp&amp;ravo</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="1356"/>
        <source>Ctrl+}</source>
        <translation>Ctrl+}</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="1358"/>
        <source>Align &amp;Justify</source>
        <translation>Zarovnat do &amp;bloku</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="1358"/>
        <source>Ctrl+J</source>
        <translation>Ctrl+J</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="1368"/>
        <source>&amp;Decrease Indent</source>
        <translation>Z&amp;menšit odsazení</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="1368"/>
        <source>Ctrl+&lt;</source>
        <translation>Ctrl+&lt;</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="1369"/>
        <source>I&amp;ncrease Indent</source>
        <translation>Zvětš&amp;it odsazení</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="1369"/>
        <source>Ctrl+&gt;</source>
        <translation>Ctrl+&gt;</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="1372"/>
        <source>Le&amp;ft to Right Block</source>
        <translation>Blok zl&amp;eva doprava</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="1374"/>
        <source>Ri&amp;ght to Left Block</source>
        <translation>Blok z&amp;prava doleva</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="1382"/>
        <source>&amp;Tools</source>
        <translation>&amp;Nástroje</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="1383"/>
        <source>&amp;Find...</source>
        <translation>&amp;Hledat...</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="1384"/>
        <source>Find &amp;Next</source>
        <translation>Najít &amp;další</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="1387"/>
        <source>Find Pre&amp;vious</source>
        <translation>Najít &amp;předchozí</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="1390"/>
        <source>&amp;Replace...</source>
        <translation>&amp;Nahradit...</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="1390"/>
        <source>Ctrl+R</source>
        <translation>Ctrl+R</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="1392"/>
        <source>Smart &amp;Quotes</source>
        <translation>Chytré &amp;uvozovky</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="1393"/>
        <source>Update &amp;Document</source>
        <translation>Obnovit &amp;dokument</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="1396"/>
        <source>Update &amp;Selection</source>
        <translation>Obnovit &amp;výběr</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="1400"/>
        <source>&amp;Spelling...</source>
        <translation>&amp;Pravopis...</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="1400"/>
        <source>F7</source>
        <translation>F7</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="1401"/>
        <source>Set &amp;Language...</source>
        <translation>Nastavit &amp;jazyk...</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="1403"/>
        <source>&amp;Timers...</source>
        <translation>Časo&amp;míry...</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="1404"/>
        <source>S&amp;ymbols...</source>
        <translation>S&amp;ymboly...</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="1405"/>
        <source>&amp;Daily Progress</source>
        <translation>&amp;Denní postup</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="1408"/>
        <source>&amp;Settings</source>
        <translation>&amp;Nastavení</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="1409"/>
        <source>Show &amp;Toolbar</source>
        <translation>Ukázat ná&amp;strojový pruh</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="1414"/>
        <source>Show &amp;Menu Icons</source>
        <translation>Ukázat &amp;nabídkové ikony</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="1420"/>
        <source>F&amp;ocused Text</source>
        <translation>Zao&amp;střený text</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="1422"/>
        <source>&amp;Fullscreen</source>
        <translation>&amp;Celá obrazovka</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="1422"/>
        <source>F11</source>
        <translation>F11</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="1424"/>
        <source>Esc</source>
        <translation>Esc</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="1428"/>
        <source>M&amp;inimize</source>
        <translation>Z&amp;menšit na panel</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="1428"/>
        <source>Ctrl+M</source>
        <translation>Ctrl+M</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="1430"/>
        <source>&amp;Themes...</source>
        <translation>&amp;Vzhled...</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="1433"/>
        <source>&amp;Preferences...</source>
        <translation>&amp;Nastavení...</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="1439"/>
        <source>Focus Off</source>
        <translation>Zaměření vypnuto</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="1441"/>
        <source>Focus One Line</source>
        <translation>Zaměření na jeden řádek</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="1443"/>
        <source>Focus Three Lines</source>
        <translation>Zaměření na tři řádky</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="1444"/>
        <source>&amp;Paragraph</source>
        <translation>&amp;Odstavec</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="1445"/>
        <source>Focus Paragraph</source>
        <translation>Zaměření na odstavec</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="1454"/>
        <source>Ctrl+Shift+`</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="1459"/>
        <source>&amp;Help</source>
        <translation>&amp;Nápověda</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="1432"/>
        <source>Application &amp;Language...</source>
        <translation>Jazyk &amp;programu...</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="400"/>
        <source>Some files were unsupported and could not be opened.</source>
        <translation>Některé soubory nebyly podporovány a nepodařilo se je otevřít.</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="1438"/>
        <source>&amp;Off</source>
        <translation>&amp;Vypnuto</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="1440"/>
        <source>One &amp;Line</source>
        <translation>Jeden řá&amp;dek</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="1442"/>
        <source>&amp;Three Lines</source>
        <translation>&amp;Tři řádky</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="1460"/>
        <source>&amp;About</source>
        <translation>&amp;O programu</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="1468"/>
        <source>About &amp;Qt</source>
        <translation>O &amp;Qt</translation>
    </message>
</context>
</TS>
